<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Finance_Advisor
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
  <meta charset="<?php bloginfo( 'charset' ); ?>">
  <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">
  <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
  <link rel="profile" href="https://gmpg.org/xfn/11">

  <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div class="site-wrapper">
  <a class="skip-link screen-reader-text" href="#content">
  <?php esc_html_e( 'Skip to content', 'finance-advisor' ); ?></a>

    <header class="site-header">
      <div class="container">

        <div class="header-left">
          <div class="logo">
            <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
              <?php the_custom_logo(); ?>
            </a>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php
              $finance_advisor_description = get_bloginfo( 'description', 'display' );
              if ( $finance_advisor_description || is_customize_preview() ) :
              ?>
                <p class="site-description"><?php echo $finance_advisor_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
            <?php endif; ?>
          </div>
        </div>

        <div class="header-right">
          <div id="site-navigation" class="main-navigation">
          
            <div class="site-links">
              <div class="menu-activator site-link">
                <span class="link nav-opener">
                  <a href="#" target="_blank" class="no-link"><span></span></a>
                </span>
              </div>
            </div>

            <?php
            wp_nav_menu( array(
              'theme_location' => 'menu-1',
              'container' => 'nav',
              'menu_id'        => 'primary-menu',
              'menu_class' => 'header-nav nav-menu',
              'fallback_cb' => 'finance_advisor_primary_navigation_fallback',
            ) );
            ?>
            
            
          </div>


          <div class="contact-detail">
            <ul class="contact-details">
              <?php if($finance_advisor_header_phone = get_theme_mod('header_phone', '+123-45678')): ?>
                <li><span class="info"><?php echo esc_html($finance_advisor_header_phone); ?></span></li>
              <?php endif; ?>
              <?php if($finance_advisor_header_email = get_theme_mod('header_email')): ?>
                <li><a href="mailto:<?php echo esc_attr($finance_advisor_header_email); ?>" class="info"><?php echo esc_html($finance_advisor_header_email); ?></a></li>
              <?php endif; ?>
            </ul>
          </div>

          <div class="site-links">
            <?php if($finance_advisor_linkedin_url = get_theme_mod('linkedin_url','#')) : ?>
              <div class="linkedin site-link">
                <span class="link">
                  <a href="<?php echo esc_url($finance_advisor_linkedin_url); ?>" target="_blank" class="linkedin-link">
                    <i class="fab fa-linkedin"></i>
                  </a>
                </span>
              </div>
            <?php endif; ?>
            
          </div>
        </div>
      </div>
    </header>
    <main class="main" id="content">
    <?php
    
    // banner
    if(is_front_page()){
      do_action('finance_advisor_banner_home');
    } else {
      do_action('finance_advisor_banner_inner');
    }
    
    
