<?php
/**
 * Finance Advisor Theme Customizer
 *
 * @package Finance_Advisor
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function finance_advisor_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'finance_advisor_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'finance_advisor_customize_partial_blogdescription',
			)
		);
	}


	/*
	* Create a section
	* Name: Headeer Options
	*/    
	$wp_customize->add_section( 'header_options', array(
		'title' => esc_html__( 'Header Options', 'finance-advisor' ),
		'priority'       => 30,
	) ); 

	$wp_customize->add_setting( 'header_phone', array(
		'sanitize_callback' => 'finance_advisor_sanitize_text',
	) );
	$wp_customize->add_control( 'header_phone', array(
		'label'    => esc_html__( 'Phone Number', 'finance-advisor' ),
		'section'  => 'header_options',		
		'type'     => 'text',
	) );

	$wp_customize->add_setting( 'header_email', array(
		'sanitize_callback' => 'finance_advisor_sanitize_text',
	) );
	$wp_customize->add_control( 'header_email', array(
		'label'    => esc_html__( 'Email Address', 'finance-advisor' ),
		'section'  => 'header_options',		
		'type'     => 'text',
	) );
	
	//linkedin url
	$wp_customize->add_setting( 'linkedin_url', array(
		'sanitize_callback' => 'finance_advisor_sanitize_url'
	) );
	$wp_customize->add_control( 'linkedin_url', array(
		'label'    => esc_html__( 'Linkedin Url', 'finance-advisor' ),
		'section'  => 'header_options',		
		'type'     => 'text',
	) );
	/*******************End if header section *********************************** */

	/*******
	 * ==================
	 * Homepage Panel
	 * ==================
	 */

	$wp_customize->add_panel('homepage_panel',array(
    'title'=>'Homepage Options',
    'description'=> esc_html__('Options for homepage customization', 'finance-advisor' ),
		'priority'=> 40,
	));

	/*
	* Create a section
	* Name: Homepage Banner
	*/  
	$wp_customize->add_section( 'banner_options', array(
		'title' => esc_html__( 'Banner Options', 'finance-advisor' ),
		'priority' => 30,
		'panel' => 'homepage_panel'
	) ); 

	$wp_customize->add_setting( 'banner_readmore_link', array(
		'sanitize_callback' => 'finance_advisor_sanitize_url',
	) );
	$wp_customize->add_control( 'banner_readmore_link', array(
		'label'    => esc_html__( 'Readmore Link', 'finance-advisor' ),
		'section'  => 'banner_options',		
		'type'     => 'url',
	) );
	/** end of banner */


	/*
	* Create a section
	* Name: Homepage About Us section
	*/
	$wp_customize->add_section( 'about_us_options', array(
		'title' => esc_html__( 'About Us Options', 'finance-advisor' ),
		'priority' => 30,
		'panel' => 'homepage_panel'
	) ); 
	$wp_customize->add_setting( 'finance_advisor_dropdownpages_setting_id', array(
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'finance_advisor_sanitize_dropdown_pages',
	) );
	
	$wp_customize->add_control( 'finance_advisor_dropdownpages_setting_id', array(
		'type' => 'dropdown-pages',
		'section' => 'about_us_options', // Add a default or your own section
		'label' => esc_html__( 'Select About us Page', 'finance-advisor' ),
		'description' => esc_html__( 'Select to displayi in about us section leave empty to remove about us section in homepage', 'finance-advisor' ),
	) );
	/** end of about us section */

	/*
	* Create a section
	* Name: Homepage Block quote section
	*/
	$wp_customize->add_section( 'block_quote_options', array(
		'title' => esc_html__( 'Block Quote Options', 'finance-advisor' ),
		'priority' => 30,
		'panel' => 'homepage_panel'
	) );

	$wp_customize->add_setting( 'block_quote_enable', array(
		'sanitize_callback' => 'finance_advisor_sanitize_checkbox'
	) );
	$wp_customize->add_control( 'block_quote_enable', array(
		'label'    => esc_html__( 'Enable Block Quote Section', 'finance-advisor' ),
		'section'  => 'block_quote_options',		
		'type'     => 'checkbox',
	) );
	
	$wp_customize->add_setting( 'block_quote_main_text', array(
		'sanitize_callback' => 'finance_advisor_sanitize_textarea',
	) );
	$wp_customize->add_control( 'block_quote_main_text', array(
		'label'    => esc_html__( 'Main Text', 'finance-advisor' ),
		'section'  => 'block_quote_options',		
		'type'     => 'textarea',
	) );
	/** End of block quote */

	/*
	* Create a section
	* Name: Homepage Services section
	*/
	$wp_customize->add_section( 'services_options', array(
		'title' => esc_html__( 'Services Options', 'finance-advisor' ),
		'priority' => 30,
		'panel' => 'homepage_panel'
	) );

	$wp_customize->add_setting( 'services_enable', array(
		'sanitize_callback' => 'finance_advisor_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'services_enable', array(
		'label'    => esc_html__( 'Enable Service Section', 'finance-advisor' ),
		'section'  => 'services_options',		
		'type'     => 'checkbox',
	) );

	$wp_customize->add_setting(
		'homepage_services_category',
		array(
				'sanitize_callback' => 'finance_advisor_sanitize_select',
				)
	);

	$wp_customize->add_control( new Finance_Advisor_Category_Dropdown( $wp_customize, 'homepage_services_category',
			array(
					'label' => esc_html__( 'Choose Services Category', 'finance-advisor' ),
					'section' => 'services_options',
					'description' => esc_html__( 'Select Category to show posts in Services Section','finance-advisor' ),
					'type' => 'select',
			)
	) );
	/** Services end **/


	/*
	* Create a Client
	* Name: Homepage Client section
	*/
	$wp_customize->add_section( 'client_options', array(
		'title' => esc_html__( 'client Options', 'finance-advisor' ),
		'priority' => 30,
		'panel' => 'homepage_panel'
	) );

	$wp_customize->add_setting( 'client_enable', array(
		'sanitize_callback' => 'finance_advisor_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'client_enable', array(
		'label'    => esc_html__( 'Enable Client Section', 'finance-advisor' ),
		'section'  => 'client_options',		
		'type'     => 'checkbox',
	) );
	

	$wp_customize->add_setting(
		'homepage_client_category',
		array(
				'sanitize_callback' => 'finance_advisor_sanitize_select',
				)
	);

	$wp_customize->add_control( new Finance_Advisor_Category_Dropdown( $wp_customize, 'homepage_client_category',
			array(
					'label' => esc_html__( 'Choose client Category', 'finance-advisor' ),
					'section' => 'client_options',
					'description' => esc_html__( 'Select Category to show posts in Client Section','finance-advisor' ),
					'type' => 'select',
			)
	) );
	/** Client end **/

		/*
	* Create a Our Blog Section
	* Name: Homepage Blog section
	*/
	$wp_customize->add_section( 'blog_options', array(
		'title' => esc_html__( 'Home Our blog Options', 'finance-advisor' ),
		'priority' => 30,
		'panel' => 'homepage_panel'
	) );

	$wp_customize->add_setting( 'our_blog_enable', array(
		'sanitize_callback' => 'finance_advisor_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'our_blog_enable', array(
		'label'    => esc_html__( 'Enable Our blog Section', 'finance-advisor' ),
		'section'  => 'blog_options',		
		'type'     => 'checkbox',
	) );


	$wp_customize->add_setting(
		'homepage_blog_category',
		array(
				'sanitize_callback' => 'finance_advisor_sanitize_select',
				)
	);

	$wp_customize->add_control( new Finance_Advisor_Category_Dropdown( $wp_customize, 'homepage_blog_category',
			array(
					'label' => esc_html__( 'Choose Blog Category', 'finance-advisor' ),
					'section' => 'blog_options',
					'description' => esc_html__( 'Select Category to show posts in Blog Section','finance-advisor' ),
					'type' => 'select',
			)
	) );
	

	/*
	* Create a section
	* Name: Homepage Contact Block Section
	*/
	$wp_customize->add_section( 'contact_block_options', array(
		'title' => esc_html__( 'Contact Block Options', 'finance-advisor' ),
		'priority' => 30,
		'panel' => 'homepage_panel'
	) );

	$wp_customize->add_setting( 'contact_quote_enable', array(
		'sanitize_callback' => 'finance_advisor_sanitize_checkbox',
	) );
	$wp_customize->add_control( 'contact_quote_enable', array(
		'label'    => esc_html__( 'Enable Contact Block Section', 'finance-advisor' ),
		'section'  => 'contact_block_options',		
		'type'     => 'checkbox',
	) );
	
	$wp_customize->add_setting( 'contact_block_main_text', array(
		'sanitize_callback' => 'finance_advisor_sanitize_textarea',
	) );
	$wp_customize->add_control( 'contact_block_main_text', array(
		'label'    => esc_html__( 'Main Text', 'finance-advisor' ),
		'section'  => 'contact_block_options',		
		'type'     => 'text',
	) );

	$wp_customize->add_setting( 'contact_block_sub_text', array(
		'sanitize_callback' => 'finance_advisor_sanitize_textarea',
	) );
	$wp_customize->add_control( 'contact_block_sub_text', array(
		'label'    => esc_html__( 'Sub Text', 'finance-advisor' ),
		'section'  => 'contact_block_options',		
		'type'     => 'textarea',
	) );


	$wp_customize->add_setting( 'contact_readmore_link', array(
		'sanitize_callback' => 'finance_advisor_sanitize_url',
	) );
	$wp_customize->add_control( 'contact_readmore_link', array(
		'label'    => esc_html__( 'Readmore Link', 'finance-advisor' ),
		'section'  => 'contact_block_options',		
		'type'     => 'url',
	) );
	/** End of block quote */



	/** Add Panel */

	/*
	* Create a section
	* Name: Footer Section
	*/  
	$wp_customize->add_section( 'footer_options', array(
		'title' => esc_html__( 'Footer Options', 'finance-advisor' ),
	) ); 

	$wp_customize->add_setting( 'footer_address', array(
		'sanitize_callback' => 'finance_advisor_sanitize_textarea',
		'default'	=> __('<strong>Address</strong> / New York, Avenue Street','finance-advisor')
	) );
	$wp_customize->add_control( 'footer_address', array(
		'label'    => esc_html__( 'Address', 'finance-advisor' ),
		'section'  => 'footer_options',		
		'type'     => 'textarea',
	) );

	$wp_customize->add_setting( 'footer_linked_link', array(
		'sanitize_callback' => 'finance_advisor_sanitize_url',
	) );
	$wp_customize->add_control( 'footer_linked_link', array(
		'label'    => esc_html__( 'Linkedin Link', 'finance-advisor' ),
		'section'  => 'footer_options',		
		'type'     => 'url',
	) );

	$wp_customize->add_setting( 'footer_fb_link', array(
		'sanitize_callback' => 'finance_advisor_sanitize_url',
	) );
	$wp_customize->add_control( 'footer_fb_link', array(
		'label'    => esc_html__( 'Facebook Link', 'finance-advisor' ),
		'section'  => 'footer_options',		
		'type'     => 'url',
	) );

	$wp_customize->add_setting( 'footer_twitter_link', array(
		'sanitize_callback' => 'finance_advisor_sanitize_url',
	) );
	$wp_customize->add_control( 'footer_twitter_link', array(
		'label'    => esc_html__( 'Twitter Link', 'finance-advisor' ),
		'section'  => 'footer_options',		
		'type'     => 'url',
	) );

}
add_action( 'customize_register', 'finance_advisor_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function finance_advisor_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function finance_advisor_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function finance_advisor_customize_preview_js() {
	wp_enqueue_script( 'finance-advisor-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), finance_advisor_version, true );
}
add_action( 'customize_preview_init', 'finance_advisor_customize_preview_js' );


// adds sanitization callback function : text 
if ( ! function_exists( 'finance_advisor_sanitize_text' ) ) :
	function finance_advisor_sanitize_text( $input ) {
		return wp_kses_post( force_balance_tags( $input ) );
	}
endif;

// adds sanitization callback function : url
if ( ! function_exists( 'finance_advisor_sanitize_url' ) ) :
	function finance_advisor_sanitize_url( $value) {
		$value = esc_url_raw( $value);
		return $value;
	}
endif;

// adds sanitization callback function : checkbox
if ( ! function_exists( 'finance_advisor_sanitize_checkbox' ) ) :
	function finance_advisor_sanitize_checkbox( $input ) {
		if ( $input == 1 ) {
			return 1;
		} else {
			return '';
		}
	}	 
endif;


// adds sanitization callback function for uploading : uploader
if ( ! function_exists( 'finance_advisor_sanitize_upload' ) ) :
	add_filter( 'finance_advisor_sanitize_image', 'finance_advisor_sanitize_upload' );
	add_filter( 'finance_advisor_sanitize_file', 'finance_advisor_sanitize_upload' );

	function finance_advisor_sanitize_upload( $input ) {        
			$output = '';        
			$filetype = wp_check_filetype($input);       
			if ( $filetype["ext"] ) {        
					$output = $input;        
			}       
			return $output;
	}
endif;

// adds sanitization callback function : textarea
if ( ! function_exists( 'finance_advisor_sanitize_textarea' ) ) :
  function finance_advisor_sanitize_textarea( $value ) {
    if ( !current_user_can('unfiltered_html') )
			$value  = stripslashes( wp_filter_post_kses( addslashes( $value ) ) ); // wp_filter_post_kses() expects slashed

    return $value;
  }
endif;

// adds sanitization callback function : page-dropdown
if ( ! function_exists( 'finance_advisor_sanitize_dropdown_pages' ) ) :
	function finance_advisor_sanitize_dropdown_pages( $page_id, $setting ) {
		// Ensure $input is an absolute integer.
		$page_id = absint( $page_id );

		// If $page_id is an ID of a published page, return it; otherwise, return the default.
		return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
	}
endif;

/**
 * Sanitize number
 *
 */
function finance_advisor_sanitize_number( $input ) {
	$output = intval($input);
	 return $output;
}

// Select field sanitization
function finance_advisor_sanitize_select( $input, $setting ) {
	return absint( $input );
}
